@@ -33,7 +33,7 @@
 #' burn_in        = estimate(specification, 10)
 #' 
 #' # estimate the model
-#' posterior      = estimate(burn_in, 20, thin = 1)
+#' posterior      = estimate(burn_in, 20)
 #' summary(posterior)
 #' 
 #' # workflow with the pipe |>
@@ -42,7 +42,7 @@
 #' us_fiscal_lsuw |>
 #'   specify_bsvar$new() |>
 #'   estimate(S = 10) |> 
-#'   estimate(S = 20, thin = 1) |> 
+#'   estimate(S = 20) |> 
 #'   summary()
 #' 
 #' @export
@@ -175,7 +175,7 @@ summary.PosteriorBSVAR = function(
 #' burn_in        = estimate(specification, 10)
 #' 
 #' # estimate the model
-#' posterior      = estimate(burn_in, 20, thin = 1)
+#' posterior      = estimate(burn_in, 20)
 #' summary(posterior)
 #' 
 #' # workflow with the pipe |>
@@ -184,7 +184,7 @@ summary.PosteriorBSVAR = function(
 #' us_fiscal_lsuw |>
 #'   specify_bsvar_sv$new() |>
 #'   estimate(S = 10) |> 
-#'   estimate(S = 20, thin = 1) |> 
+#'   estimate(S = 20) |> 
 #'   summary()
 #' 
 #' @export
@@ -320,7 +320,7 @@ summary.PosteriorBSVARSV = function(
 #' burn_in        = estimate(specification, 10)
 #' 
 #' # estimate the model
-#' posterior      = estimate(burn_in, 20, thin = 1)
+#' posterior      = estimate(burn_in, 20)
 #' summary(posterior)
 #' 
 #' # workflow with the pipe |>
@@ -329,7 +329,7 @@ summary.PosteriorBSVARSV = function(
 #' us_fiscal_lsuw |>
 #'   specify_bsvar_msh$new() |>
 #'   estimate(S = 10) |> 
-#'   estimate(S = 20, thin = 1) |> 
+#'   estimate(S = 20) |> 
 #'   summary()
 #' 
 #' @export
@@ -464,7 +464,7 @@ summary.PosteriorBSVARMSH = function(
 #' burn_in        = estimate(specification, 10)
 #' 
 #' # estimate the model
-#' posterior      = estimate(burn_in, 20, thin = 1)
+#' posterior      = estimate(burn_in, 20)
 #' summary(posterior)
 #' 
 #' # workflow with the pipe |>
@@ -473,7 +473,7 @@ summary.PosteriorBSVARMSH = function(
 #' us_fiscal_lsuw |>
 #'   specify_bsvar_mix$new() |>
 #'   estimate(S = 10) |> 
-#'   estimate(S = 20, thin = 1) |> 
+#'   estimate(S = 20) |> 
 #'   summary()
 #' 
 #' @export
@@ -568,6 +568,153 @@ summary.PosteriorBSVARMIX = function(
 
 
 
+#' @title Provides posterior summary of Structural VAR with t-distributed shocks estimation
+#'
+#' @description Provides posterior mean, standard deviations, as well as 5 and 95 
+#' percentiles of the parameters: the structural matrix \eqn{B}, autoregressive 
+#' parameters \eqn{A}, hyper-parameters, and Student-t degrees-of-freedom 
+#' parameter \eqn{\nu}.
+#' 
+#' @param object an object of class PosteriorBSVART obtained using the
+#' \code{estimate()} function applied to homoskedastic Bayesian Structural VAR
+#' model specification set by function \code{specify_bsvar$new()} containing 
+#' draws from the  posterior distribution of the parameters. 
+#' @param ... additional arguments affecting the summary produced.
+#' 
+#' @return A list reporting the posterior mean, standard deviations, as well as 5 and 95 
+#' percentiles of the parameters: the structural matrix \eqn{B}, autoregressive 
+#' parameters \eqn{A}, hyper-parameters, and Student-t degrees-of-freedom 
+#' parameter \eqn{\nu}.
+#' 
+#' @method summary PosteriorBSVART
+#' 
+#' @seealso \code{\link{estimate}}, \code{\link{specify_bsvar_t}}
+#'
+#' @author Tomasz Woźniak \email{wozniak.tom@pm.me}
+#' 
+#' @examples
+#' # upload data
+#' data(us_fiscal_lsuw)
+#' 
+#' # specify the model and set seed
+#' set.seed(123)
+#' specification  = specify_bsvar_t$new(us_fiscal_lsuw)
+#' 
+#' # run the burn-in
+#' burn_in        = estimate(specification, 10)
+#' 
+#' # estimate the model
+#' posterior      = estimate(burn_in, 20)
+#' summary(posterior)
+#' 
+#' # workflow with the pipe |>
+#' ############################################################
+#' set.seed(123)
+#' us_fiscal_lsuw |>
+#'   specify_bsvar_t$new() |>
+#'   estimate(S = 10) |> 
+#'   estimate(S = 20) |> 
+#'   summary()
+#' 
+#' @export
+summary.PosteriorBSVART = function(
+    object,
+    ...
+) {
+  
+  cat(
+    " **************************************************|\n",
+    "bsvars: Bayesian Structural Vector Autoregressions|\n",
+    "**************************************************|\n",
+    "  Posterior summary of the parameters             |\n",
+    "**************************************************|\n"
+  )
+  
+  N         = dim(object$posterior$A)[1]
+  p         = object$last_draw$p
+  K         = dim(object$last_draw$data_matrices$X)[1]
+  d         = K - N * p
+  
+  out       = list()
+  out$B     = list()
+  out$A     = list()
+  out$hyper = list()
+  
+  param     = c("B", "A")
+  
+  for (n in 1:N) {
+    which_par = which(colSums(object$last_draw$identification$VB[[n]]) == 1)
+    out$B[[n]] = matrix(
+      cbind(
+        apply(object$posterior$B[n,,], 1, mean),
+        apply(object$posterior$B[n,,], 1, sd),
+        apply(object$posterior$B[n,,], 1, quantile, probs = 0.05),
+        apply(object$posterior$B[n,,], 1, quantile, probs = 0.95)
+      )[which_par,],
+      ncol = 4
+    )
+    colnames(out$B[[n]]) = c("mean", "sd", "5% quantile", "95% quantile")
+    rownames(out$B[[n]]) = paste0("B[", n, ",", which_par, "]")  
+    
+    out$A[[n]] = cbind(
+      apply(object$posterior$A[n,,], 1, mean),
+      apply(object$posterior$A[n,,], 1, sd),
+      apply(object$posterior$A[n,,], 1, quantile, probs = 0.05),
+      apply(object$posterior$A[n,,], 1, quantile, probs = 0.95)
+    )
+    colnames(out$A[[n]]) = c("mean", "sd", "5% quantile", "95% quantile")
+    
+    Anames  = c(
+      paste0(
+        rep("lag", p * N),
+        kronecker((1:p), rep(1, N)),
+        rep("_var", p * N),
+        kronecker((1:N), rep(1, p))
+      ),
+      "const"
+    )
+    if (d > 1) {
+      Anames = c(Anames, paste0("exo", 1:(d - 1)))
+    }
+    rownames(out$A[[n]]) = Anames
+  } # END n loop
+  
+  names(out$B) = paste0("equation", 1:N)
+  names(out$A) = paste0("equation", 1:N)
+  
+  for (i in 1:2) {
+    out$hyper[[i]] = cbind(
+      apply(object$posterior$hyper[,i,], 1, mean),
+      apply(object$posterior$hyper[,i,], 1, sd),
+      apply(object$posterior$hyper[,i,], 1, quantile, probs = 0.05),
+      apply(object$posterior$hyper[,i,], 1, quantile, probs = 0.95)
+    )
+    
+    colnames(out$hyper[[i]]) = c("mean", "sd", "5% quantile", "95% quantile")
+    rownames(out$hyper[[i]]) = c(
+      paste0(
+        rep(param[i], N),
+        "[",
+        kronecker(rep(1, 2), (1:N)),
+        c(rep(",]_shrinkage", N), rep(",]_shrinkage_scale", N))
+      ),
+      paste0(param[i], "_global_scale")
+    )
+  } # END i loop
+  names(out$hyper) = param
+  
+  out$df = c(
+    mean(object$posterior$df),
+    sd(object$posterior$df),
+    quantile(object$posterior$df, probs = 0.05),
+    quantile(object$posterior$df, probs = 0.95)
+  )
+  names(out$df) = c("mean", "sd", "5% quantile", "95% quantile")
+  
+  return(out)
+} # END summary.PosteriorBSVART
+
+
 
 
 
@@ -696,7 +843,7 @@ summary.PosteriorSigma = function(
 #' burn_in        = estimate(specification, 10)
 #' 
 #' # estimate the model
-#' posterior      = estimate(burn_in, 20, thin = 1)
+#' posterior      = estimate(burn_in, 20)
 #' 
 #' # compute fitted values
 #' fitted         = compute_fitted_values(posterior)
@@ -708,7 +855,7 @@ summary.PosteriorSigma = function(
 #' us_fiscal_lsuw |>
 #'   specify_bsvar$new() |>
 #'   estimate(S = 10) |> 
-#'   estimate(S = 20, thin = 1) |> 
+#'   estimate(S = 20) |> 
 #'   compute_fitted_values() |>
 #'   summary() -> fitted_summary
 #' 
@@ -786,7 +933,7 @@ summary.PosteriorFitted = function(
 #' burn_in        = estimate(specification, 10)
 #' 
 #' # estimate the model
-#' posterior      = estimate(burn_in, 20, thin = 1)
+#' posterior      = estimate(burn_in, 20)
 #' 
 #' # compute historical decompositions
 #' hds            = compute_historical_decompositions(posterior)
@@ -798,7 +945,7 @@ summary.PosteriorFitted = function(
 #' diff(us_fiscal_lsuw) |>
 #'   specify_bsvar$new() |>
 #'   estimate(S = 10) |> 
-#'   estimate(S = 20, thin = 1) |> 
+#'   estimate(S = 20) |> 
 #'   compute_historical_decompositions() |>
 #'   summary() -> hds_summary
 #' 
@@ -871,7 +1018,7 @@ summary.PosteriorHD = function(
 #' burn_in        = estimate(specification, 10)
 #' 
 #' # estimate the model
-#' posterior      = estimate(burn_in, 20, thin = 1)
+#' posterior      = estimate(burn_in, 20)
 #' 
 #' # compute impulse responses
 #' irf            = compute_impulse_responses(posterior, horizon = 4)
@@ -883,7 +1030,7 @@ summary.PosteriorHD = function(
 #' us_fiscal_lsuw |>
 #'   specify_bsvar$new() |>
 #'   estimate(S = 10) |> 
-#'   estimate(S = 20, thin = 1) |> 
+#'   estimate(S = 20) |> 
 #'   compute_impulse_responses(horizon = 4) |>
 #'   summary() -> irf_summary
 #' 
@@ -959,7 +1106,7 @@ summary.PosteriorIR = function(
 #' burn_in        = estimate(specification, 10)
 #' 
 #' # estimate the model
-#' posterior      = estimate(burn_in, 20, thin = 1)
+#' posterior      = estimate(burn_in, 20)
 #' 
 #' # compute regime probabilities
 #' rp             = compute_regime_probabilities(posterior)
@@ -971,7 +1118,7 @@ summary.PosteriorIR = function(
 #' us_fiscal_lsuw |>
 #'   specify_bsvar_msh$new() |>
 #'   estimate(S = 10) |> 
-#'   estimate(S = 20, thin = 1) |> 
+#'   estimate(S = 20) |> 
 #'   compute_regime_probabilities() |>
 #'   summary() -> rp_summary
 #' 
@@ -1043,7 +1190,7 @@ summary.PosteriorRegimePr = function(
 #' burn_in        = estimate(specification, 10)
 #' 
 #' # estimate the model
-#' posterior      = estimate(burn_in, 20, thin = 1)
+#' posterior      = estimate(burn_in, 20)
 #' 
 #' # compute structural shocks
 #' shocks         = compute_structural_shocks(posterior)
@@ -1055,7 +1202,7 @@ summary.PosteriorRegimePr = function(
 #' us_fiscal_lsuw |>
 #'   specify_bsvar$new() |>
 #'   estimate(S = 10) |> 
-#'   estimate(S = 20, thin = 1) |> 
+#'   estimate(S = 20) |> 
 #'   compute_structural_shocks() |>
 #'   summary() -> shocks_summary
 #' 
@@ -1129,7 +1276,7 @@ summary.PosteriorShocks = function(
 #' burn_in        = estimate(specification, 10)
 #' 
 #' # estimate the model
-#' posterior      = estimate(burn_in, 20, thin = 1)
+#' posterior      = estimate(burn_in, 20)
 #' 
 #' # compute forecast error variance decompositions
 #' fevd           = compute_variance_decompositions(posterior, horizon = 4)
@@ -1141,7 +1288,7 @@ summary.PosteriorShocks = function(
 #' us_fiscal_lsuw |>
 #'   specify_bsvar$new() |>
 #'   estimate(S = 10) |> 
-#'   estimate(S = 20, thin = 1) |> 
+#'   estimate(S = 20) |> 
 #'   compute_variance_decompositions(horizon = 4) |>
 #'   summary() -> fevd_summary
 #' 
@@ -1211,7 +1358,7 @@ summary.PosteriorFEVD = function(
 #' burn_in        = estimate(specification, 10)
 #' 
 #' # estimate the model
-#' posterior      = estimate(burn_in, 20, thin = 1)
+#' posterior      = estimate(burn_in, 20)
 #' 
 #' # forecast
 #' fore           = forecast(posterior, horizon = 2)
@@ -1223,7 +1370,7 @@ summary.PosteriorFEVD = function(
 #' us_fiscal_lsuw |>
 #'   specify_bsvar$new() |>
 #'   estimate(S = 10) |> 
-#'   estimate(S = 20, thin = 1) |> 
+#'   estimate(S = 20) |> 
 #'   forecast(horizon = 2) |>
 #'   summary() -> fore_summary
 #' 
@@ -1295,7 +1442,7 @@ summary.Forecasts = function(
 #' set.seed(123)
 #' 
 #' # estimate the model
-#' posterior      = estimate(specification, 10, thin = 1)
+#' posterior      = estimate(specification, 10)
 #' 
 #' # verify heteroskedasticity
 #' sddr           = verify_volatility(posterior)
@@ -1306,7 +1453,7 @@ summary.Forecasts = function(
 #' set.seed(123)
 #' us_fiscal_lsuw |>
 #'   specify_bsvar_msh$new(p = 1, M = 2) |>
-#'   estimate(S = 10, thin = 1) |> 
+#'   estimate(S = 10) |> 
 #'   verify_volatility() |> 
 #'   summary() -> sddr_summary
 #' 
@@ -1330,7 +1477,7 @@ summary.SDDRvolatility = function(
   
   out = cbind(
     object$logSDDR,
-    object$log_SDDR_se,
+    object$logSDDR_se,
     exp_sddr / (1 + exp_sddr),
     1 / (1 + exp_sddr)
   )
@@ -1374,7 +1521,7 @@ summary.SDDRvolatility = function(
 #' set.seed(123)
 #' 
 #' # estimate the model
-#' posterior      = estimate(specification, 10, thin = 1)
+#' posterior      = estimate(specification, 10)
 #' 
 #' # verify autoregression
 #' H0             = matrix(NA, ncol(us_fiscal_lsuw), ncol(us_fiscal_lsuw) + 1)
@@ -1387,7 +1534,7 @@ summary.SDDRvolatility = function(
 #' set.seed(123)
 #' us_fiscal_lsuw |>
 #'   specify_bsvar_sv$new(p = 1) |>
-#'   estimate(S = 10, thin = 1) |> 
+#'   estimate(S = 10) |> 
 #'   verify_autoregression(hypothesis = H0) |> 
 #'   summary() -> sddr_summary
 #' 
@@ -1419,3 +1566,335 @@ summary.SDDRautoregression = function(
   
   return(out)
 } # END summary.SDDRautoregression
+
+
+
+
+
+#' @title Provides summary of verifying homoskedasticity
+#'
+#' @description Provides summary of the Savage-Dickey density ratios
+#' for verification of structural shocks homoskedasticity. The outcomes can be
+#' used to make probabilistic statements about identification through 
+#' heteroskedasticity following Lütkepohl, Shang, Uzeda & Woźniak (2024).
+#' 
+#' @param object an object of class \code{SDDRidSV} obtained using the
+#' \code{\link{verify_identification.PosteriorBSVARSV}} function. 
+#' @param ... additional arguments affecting the summary produced.
+#' 
+#' @return A table reporting the logarithm of Bayes factors of homoskedastic to
+#' heteroskedastic posterior odds \code{"log(SDDR)"} for each structural shock, 
+#' their numerical standard errors \code{"NSE"}, and the implied posterior 
+#' probability of the homoskedasticity and heteroskedasticity hypothesis, 
+#' \code{"Pr[homoskedasticity|data]"} and \code{"Pr[heteroskedasticity|data]"} 
+#' respectively.
+#' 
+#' @references 
+#' Lütkepohl, H., Shang, F., Uzeda, L., and Woźniak, T. (2024) Partial Identification of Heteroskedastic Structural VARs: Theory and Bayesian Inference. \emph{University of Melbourne Working Paper}, 1--57, \doi{10.48550/arXiv.2404.11057}.
+#' 
+#' @method summary SDDRidSV
+#' 
+#' @seealso \code{\link{verify_identification.PosteriorBSVARSV}}
+#'
+#' @author Tomasz Woźniak \email{wozniak.tom@pm.me}
+#' 
+#' @examples
+#' # upload data
+#' data(us_fiscal_lsuw)
+#' 
+#' # specify the model and set seed
+#' specification  = specify_bsvar_sv$new(us_fiscal_lsuw)
+#' set.seed(123)
+#' 
+#' # estimate the model
+#' posterior      = estimate(specification, 10)
+#' 
+#' # verify heteroskedasticity
+#' sddr           = verify_identification(posterior)
+#' summary(sddr)
+#' 
+#' # workflow with the pipe |>
+#' ############################################################
+#' set.seed(123)
+#' us_fiscal_lsuw |>
+#'   specify_bsvar_sv$new() |>
+#'   estimate(S = 10) |> 
+#'   verify_identification() |> 
+#'   summary() -> sddr_summary
+#' 
+#' @export
+summary.SDDRidSV = function(
+    object,
+    ...
+) {
+  
+  cat(
+    " **************************************************|\n",
+    "bsvars: Bayesian Structural Vector Autoregressions|\n",
+    "**************************************************|\n",
+    "  Summary of identification verification          |\n",
+    "    H0: omega_n = 0  [homoskedasticity]           |\n",
+    "    H1: omega_n != 0 [heteroskedasticity]         |\n",
+    "**************************************************|\n"
+  )
+  
+  N         = nrow(object$logSDDR)
+  exp_sddr  = exp(object$logSDDR)
+  
+  out = cbind(
+    object$logSDDR,
+    object$logSDDR_se,
+    exp_sddr / (1 + exp_sddr),
+    1 / (1 + exp_sddr)
+  )
+  colnames(out) = c("log(SDDR)", "NSE", "Pr[H0|data]", "Pr[H1|data]")
+  rownames(out) = paste0("shock ", 1:N)
+  
+  return(out)
+} # END summary.SDDRidSV
+
+
+
+
+#' @title Provides summary of verifying homoskedasticity
+#'
+#' @description Provides summary of the Savage-Dickey density ratios
+#' for verification of structural shocks homoskedasticity. The outcomes can be
+#' used to make probabilistic statements about identification through 
+#' heteroskedasticity closely following ideas by Lütkepohl& Woźniak (2020).
+#' 
+#' @param object an object of class \code{SDDRidMSH} obtained using the
+#' \code{\link{verify_identification.PosteriorBSVARMSH}} function. 
+#' @param ... additional arguments affecting the summary produced.
+#' 
+#' @return A table reporting the logarithm of Bayes factors of homoskedastic to
+#' heteroskedastic posterior odds \code{"log(SDDR)"} for each structural shock, 
+#' their numerical standard errors \code{"NSE"}, and the implied posterior 
+#' probability of the homoskedasticity and heteroskedasticity hypothesis, 
+#' \code{"Pr[homoskedasticity|data]"} and \code{"Pr[heteroskedasticity|data]"} 
+#' respectively.
+#' 
+#' @references 
+#' Lütkepohl, H., and Woźniak, T., (2020) Bayesian Inference for Structural Vector Autoregressions Identified by Markov-Switching Heteroskedasticity. \emph{Journal of Economic Dynamics and Control} \bold{113}, 103862, \doi{10.1016/j.jedc.2020.103862}.
+#' 
+#' @method summary SDDRidMSH
+#' 
+#' @seealso \code{\link{verify_identification.PosteriorBSVARMSH}}
+#'
+#' @author Tomasz Woźniak \email{wozniak.tom@pm.me}
+#' 
+#' @examples
+#' # upload data
+#' data(us_fiscal_lsuw)
+#' 
+#' # specify the model and set seed
+#' specification  = specify_bsvar_msh$new(us_fiscal_lsuw, M = 2)
+#' set.seed(123)
+#' 
+#' # estimate the model
+#' posterior      = estimate(specification, 10)
+#' 
+#' # verify heteroskedasticity
+#' sddr           = verify_identification(posterior)
+#' summary(sddr)
+#' 
+#' # workflow with the pipe |>
+#' ############################################################
+#' set.seed(123)
+#' us_fiscal_lsuw |>
+#'   specify_bsvar_msh$new(M = 2) |>
+#'   estimate(S = 10) |> 
+#'   verify_identification() |> 
+#'   summary() -> sddr_summary
+#' 
+#' @export
+summary.SDDRidMSH = function(
+    object,
+    ...
+) {
+  
+  cat(
+    " **************************************************|\n",
+    "bsvars: Bayesian Structural Vector Autoregressions|\n",
+    "**************************************************|\n",
+    "  Summary of identification verification          |\n",
+    "  H0: s^2_nm  = 1 for all m  [homoskedasticity]   |\n",
+    "  H1: s^2_nm != 1 for some m [heteroskedasticity] |\n",
+    "**************************************************|\n"
+  )
+  
+  N         = nrow(object$logSDDR)
+  exp_sddr  = exp(object$logSDDR)
+  
+  out = cbind(
+    object$logSDDR,
+    object$logSDDR_se,
+    exp_sddr / (1 + exp_sddr),
+    1 / (1 + exp_sddr)
+  )
+  colnames(out) = c("log(SDDR)", "NSE", "Pr[H0|data]", "Pr[H1|data]")
+  rownames(out) = paste0("shock ", 1:N)
+  
+  return(out)
+} # END summary.SDDRidMSH
+
+
+
+#' @title Provides summary of verifying shocks' normality
+#'
+#' @description Provides summary of the Savage-Dickey density ratios
+#' for verification of structural shocks normality. The outcomes can be
+#' used to make probabilistic statements about identification through 
+#' non-normality.
+#' 
+#' @param object an object of class \code{SDDRidMIX} obtained using the
+#' \code{\link{verify_identification.PosteriorBSVARMIX}} function. 
+#' @param ... additional arguments affecting the summary produced.
+#' 
+#' @return A table reporting the logarithm of Bayes factors of normal to
+#' non-normal shocks posterior odds \code{"log(SDDR)"} for each structural shock, 
+#' their numerical standard errors \code{"NSE"}, and the implied posterior 
+#' probability of the normality and non-normality hypothesis, 
+#' \code{"Pr[normal|data]"} and \code{"Pr[non-normal|data]"} 
+#' respectively.
+#' 
+#' @method summary SDDRidMIX
+#' 
+#' @seealso \code{\link{verify_identification.PosteriorBSVARMIX}}
+#'
+#' @author Tomasz Woźniak \email{wozniak.tom@pm.me}
+#' 
+#' @examples
+#' # upload data
+#' data(us_fiscal_lsuw)
+#' 
+#' # specify the model and set seed
+#' specification  = specify_bsvar_mix$new(us_fiscal_lsuw, M = 2)
+#' set.seed(123)
+#' 
+#' # estimate the model
+#' posterior      = estimate(specification, 10)
+#' 
+#' # verify heteroskedasticity
+#' sddr           = verify_identification(posterior)
+#' summary(sddr)
+#' 
+#' # workflow with the pipe |>
+#' ############################################################
+#' set.seed(123)
+#' us_fiscal_lsuw |>
+#'   specify_bsvar_mix$new(M = 2) |>
+#'   estimate(S = 10) |> 
+#'   verify_identification() |> 
+#'   summary() -> sddr_summary
+#' 
+#' @export
+summary.SDDRidMIX = function(
+    object,
+    ...
+) {
+  
+  cat(
+    " **************************************************|\n",
+    "bsvars: Bayesian Structural Vector Autoregressions|\n",
+    "**************************************************|\n",
+    "  Summary of identification verification          |\n",
+    "  H0: s^2_nm  = 1 for all m  [normal]             |\n",
+    "  H1: s^2_nm != 1 for some m [non-normal]         |\n",
+    "**************************************************|\n"
+  )
+  
+  N         = nrow(object$logSDDR)
+  exp_sddr  = exp(object$logSDDR)
+  
+  out = cbind(
+    object$logSDDR,
+    object$logSDDR_se,
+    exp_sddr / (1 + exp_sddr),
+    1 / (1 + exp_sddr)
+  )
+  colnames(out) = c("log(SDDR)", "NSE", "Pr[H0|data]", "Pr[H1|data]")
+  rownames(out) = paste0("shock ", 1:N)
+  
+  return(out)
+} # END summary.SDDRidMIX
+
+
+
+#' @title Provides summary of verifying shocks' normality
+#'
+#' @description Provides summary of the Savage-Dickey density ratios
+#' for verification of structural shocks normality. The outcomes can be
+#' used to make probabilistic statements about identification through 
+#' non-normality.
+#' 
+#' @param object an object of class \code{SDDRidT} obtained using the
+#' \code{\link{verify_identification.PosteriorBSVART}} function. 
+#' @param ... additional arguments affecting the summary produced.
+#' 
+#' @return A table reporting the Bayes factor of normal to
+#' Student-t shocks posterior odds \code{"SDDR"} as well as its logarithm 
+#' \code{"log(SDDR)"}for each structural shock, and the implied posterior 
+#' probability of the normality and Student-t hypothesis, 
+#' \code{"Pr[normal|data]"} and \code{"Pr[Student-t|data]"} 
+#' respectively.
+#' 
+#' @method summary SDDRidT
+#' 
+#' @seealso \code{\link{verify_identification.PosteriorBSVART}}
+#'
+#' @author Tomasz Woźniak \email{wozniak.tom@pm.me}
+#' 
+#' @examples
+#' # upload data
+#' data(us_fiscal_lsuw)
+#' 
+#' # specify the model and set seed
+#' specification  = specify_bsvar_t$new(us_fiscal_lsuw)
+#' set.seed(123)
+#' 
+#' # estimate the model
+#' posterior      = estimate(specification, 10)
+#' 
+#' # verify heteroskedasticity
+#' sddr           = verify_identification(posterior)
+#' summary(sddr)
+#' 
+#' # workflow with the pipe |>
+#' ############################################################
+#' set.seed(123)
+#' us_fiscal_lsuw |>
+#'   specify_bsvar_t$new() |>
+#'   estimate(S = 10) |> 
+#'   verify_identification() |> 
+#'   summary() -> sddr_summary
+#' 
+#' @export
+summary.SDDRidT = function(
+    object,
+    ...
+) {
+  
+  cat(
+    " **************************************************|\n",
+    "bsvars: Bayesian Structural Vector Autoregressions|\n",
+    "**************************************************|\n",
+    "  Summary of identification verification          |\n",
+    "  H0: df = Inf    [normal shocks]                 |\n",
+    "  H1: df != Inf   [Student-t shocks]              |\n",
+    "**************************************************|\n"
+  )
+  
+  exp_sddr  = object$SDDR
+  
+  out = cbind(
+    object$logSDDR,
+    object$SDDR,
+    exp_sddr / (1 + exp_sddr),
+    1 / (1 + exp_sddr)
+  )
+  colnames(out) = c("log(SDDR)", "SDDR", "Pr[H0|data]", "Pr[H1|data]")
+  rownames(out) = ""
+  
+  return(out)
+} # END summary.SDDRidT
